<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <location filename="language.h" line="31"/>
        <source>Afar</source>
        <translation>ئافار تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="32"/>
        <source>Afrikaans</source>
        <translation>جەنۇبىي ئافرىقا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="33"/>
        <source>አማርኛ</source>
        <translation>ئامخارا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="34"/>
        <source>عربية</source>
        <translation>ئەرەب تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="35"/>
        <source>অসমীয়া</source>
        <translation>ئاسسام تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="36"/>
        <source>Asturianu</source>
        <translation>ئاستۇرىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="37"/>
        <source>Беларуская</source>
        <translation>بېلورۇس تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="38"/>
        <source>Biełaruskaja łacinka</source>
        <translation>بېلورۇس لاتىن تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="39"/>
        <source>Български</source>
        <translation>بۇلغارىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="40"/>
        <source>বাংলা</source>
        <translation>بىنگال تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="41"/>
        <source>বাংলা (ভারত)</source>
        <translation>بىنگال تىلى (ھىندىستان)</translation>
    </message>
    <message>
        <location filename="language.h" line="42"/>
        <source>བོད་སྐད།</source>
        <translation>زاڭزۇ تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="43"/>
        <source>Brezhoneg</source>
        <translation>برېتون تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="44"/>
        <source>Bosanski</source>
        <translation>بوسنىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="45"/>
        <source>Català</source>
        <translation>كاتالان تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="46"/>
        <source>Qırımtatarca</source>
        <translation>قېرىم تۈرك تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="47"/>
        <source>Český</source>
        <translation>چېخ تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="48"/>
        <source>Kaszëbsczi</source>
        <translation>كۇشۇبى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="49"/>
        <source>Чăвашла</source>
        <translation>چۇۋاش تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="50"/>
        <source>Cymraeg</source>
        <translation>ۋېلش تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="51"/>
        <source>Dansk</source>
        <translation>دانىش تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="52"/>
        <source>Deutsch</source>
        <translation>نېمىس تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="53"/>
        <source>ཇོང་ཁ</source>
        <translation>بۇدان تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="54"/>
        <source>Ελληνικά</source>
        <translation>گرېك تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="55"/>
        <source>British English</source>
        <translation>ئەنگلىيە ئىنگلىزچىسى</translation>
    </message>
    <message>
        <location filename="language.h" line="56"/>
        <source>American English</source>
        <translation>ئامېرىكا ئىنگلىزچىسى</translation>
    </message>
    <message>
        <location filename="language.h" line="57"/>
        <source>Español</source>
        <translation>ئىسپان تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="58"/>
        <source>Eesti</source>
        <translation>ئېستون تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="59"/>
        <source>Euskara</source>
        <translation>باسكى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="60"/>
        <source>فارسی</source>
        <translation>پارس تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="61"/>
        <source>Suomi</source>
        <translation>فىنلاندىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="62"/>
        <source>Føroyskt</source>
        <translation>فارو تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="63"/>
        <source>Français</source>
        <translation>فرانسۇز تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="64"/>
        <source>Frysk</source>
        <translation>غەربىي فرىس تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="65"/>
        <source>Gaeilge</source>
        <translation>ئىرېلاندىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="66"/>
        <source>Gàidhlig</source>
        <translation>گا ئېل تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="67"/>
        <source>Galego</source>
        <translation>گالىتسىيان تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="68"/>
        <source>ગુજરાતી </source>
        <translation>گۇجارات تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="69"/>
        <source>Gaelg</source>
        <translation>مەنىش تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="70"/>
        <source>هَوُسَ</source>
        <translation>خائۇسا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="71"/>
        <source>עברית</source>
        <translation>ھېبرېۋ تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="72"/>
        <source>हिन्दी</source>
        <translation>ھىندى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="73"/>
        <source>Chhattisgarhi</source>
        <translation>چاتتىسگارھى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="74"/>
        <source>Hrvatski</source>
        <translation>كرودىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="75"/>
        <source>Hornjoserbsce</source>
        <translation>سوبرالىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="76"/>
        <source>Magyar</source>
        <translation>ۋېنگرىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="77"/>
        <source>Հայերեն</source>
        <translation>ئەرمەن تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="78"/>
        <source>Indonesia</source>
        <translation>ھىندونېزىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="79"/>
        <source>Iñupiak</source>
        <translation>ئىنۇپىك تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="80"/>
        <source>Íslenska</source>
        <translation>ئىسلاندىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="81"/>
        <source>Italiano</source>
        <translation>ئىتاليان تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="82"/>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>ئىنۇكتىتۇت تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="83"/>
        <source>日本語</source>
        <translation>ياپون تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="84"/>
        <source>ქართული</source>
        <translation>گرۇزىن تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="85"/>
        <source>Қазақша</source>
        <translation>قازاق تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="86"/>
        <source>Kalaallisut</source>
        <translation>گرېنلاندىك تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="87"/>
        <source>ខ្មែរ</source>
        <translation>كخمېر تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="88"/>
        <source>ಕನ್ನಡ</source>
        <translation>كانادا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="89"/>
        <source>한국어</source>
        <translation>چاۋشيەن تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="90"/>
        <source>कश्मीरी - (كشميري)</source>
        <translation>كەشمىر تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="91"/>
        <source>Kurdî</source>
        <translation>كۇرد تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="92"/>
        <source>Kernewek</source>
        <translation>كورنۋېل تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="93"/>
        <source>Кыргызча</source>
        <translation>قىرغىز تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="94"/>
        <source>Lëtzebuergesch</source>
        <translation>ليۇكسېمبۇرگ تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="95"/>
        <source>Limburgs</source>
        <translation>لىمبۇرگېر تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="96"/>
        <source>ລາວ</source>
        <translation>لائۇس تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="97"/>
        <source>Lietuvių</source>
        <translation>لىتۋا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="98"/>
        <source>Latviešu</source>
        <translation>لاتۋىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="99"/>
        <source>Maithili</source>
        <translation>ماتىلى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="100"/>
        <source>Malagasy</source>
        <translation>مالگاش تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="101"/>
        <source>Ebon</source>
        <translation>ئېبون تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="102"/>
        <source>Māori</source>
        <translation>ماۋرى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="103"/>
        <source>Македонски</source>
        <translation>ماكېدون تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="104"/>
        <source>മലയാളം</source>
        <translation>مالايالام تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="105"/>
        <source>Монгол</source>
        <translation>موڭغۇل تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="106"/>
        <source>मराठी</source>
        <translation>ماراتى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="107"/>
        <source>Bahasa Melayu</source>
        <translation>مالاي تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="108"/>
        <source>Malti</source>
        <translation>مالتا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="109"/>
        <source>Myanmasa</source>
        <translation>بىرما تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="110"/>
        <source>Ekakairũ Naoero</source>
        <translation>خوككېئىن تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="111"/>
        <source>Norsk (bokmål)</source>
        <translation>نورۋېگىيە تىلى (بوكمال تىلى)</translation>
    </message>
    <message>
        <location filename="language.h" line="112"/>
        <source>Plattdüütsch</source>
        <translation>شىمالىي گېرمانىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="113"/>
        <source>नेपाली</source>
        <translation>نېپال تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="114"/>
        <source>Nederlands</source>
        <translation>گوللاندىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="115"/>
        <source>Norsk (nynorsk)</source>
        <translation>نورۋېگىيە تىلى (يېڭى نورۋېگىيە تىلى)</translation>
    </message>
    <message>
        <location filename="language.h" line="116"/>
        <source>IsiNdebele</source>
        <translation>جەنۇبىي ندېبېلې تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="117"/>
        <source>Sesotho sa Leboa</source>
        <translation>شىمالىي سوتو تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="118"/>
        <source>Occitan</source>
        <translation>ئاۋكلاند تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="119"/>
        <source>Oromoo</source>
        <translation>ئورومو تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="120"/>
        <source>ଓଡ଼ିଆ</source>
        <translation>ئورىيا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="121"/>
        <source>Иронау</source>
        <translation>ئوسسېت تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="122"/>
        <source>ਪੰਜਾਬੀ</source>
        <translation>پەنجاب تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="123"/>
        <source>Polski</source>
        <translation>پولەك تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="124"/>
        <source>پښتو</source>
        <translation>پۇشتۇ تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="125"/>
        <source>Português</source>
        <translation>پورتۇگال تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="126"/>
        <source>Português do Brasil</source>
        <translation>پورتۇگال تىلى (بىرازىلىيە)</translation>
    </message>
    <message>
        <location filename="language.h" line="127"/>
        <source>Română</source>
        <translation>رۇمىنىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="128"/>
        <source>Русский</source>
        <translation>رۇس تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="129"/>
        <source>Kinyarwanda</source>
        <translation>رۋاندا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="130"/>
        <source>संस्कृत</source>
        <translation>سانسكرىت تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="131"/>
        <source>Sardu</source>
        <translation>ساردىيان تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="132"/>
        <source>سنڌي</source>
        <translation>سىندى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="133"/>
        <source>Sámegiella</source>
        <translation>شىمالىي سامى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="134"/>
        <source>සිංහල</source>
        <translation>سىنگال تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="135"/>
        <source>Slovenčina</source>
        <translation>سلوۋاك تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="136"/>
        <source>Slovenščina</source>
        <translation>سلوۋېنىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="137"/>
        <source>Soomaaliga</source>
        <translation>سومالى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="138"/>
        <source>Shqip</source>
        <translation>ئالبان تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="139"/>
        <source>Српски</source>
        <translation>سېرب تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="140"/>
        <source>srpski (latinica)</source>
        <translation>سېربىيە تىلى (لاتىنچە)</translation>
    </message>
    <message>
        <location filename="language.h" line="141"/>
        <source>SiSwati</source>
        <translation>سۋاتى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="142"/>
        <source>Sesotho</source>
        <translation>جەنۇبىي سوتو تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="143"/>
        <source>Svenska</source>
        <translation>شۋېتسىيە تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="144"/>
        <source>Swahili</source>
        <translation>سۋاھلى تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="145"/>
        <source>தமிழ்</source>
        <translation>تامىل تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="146"/>
        <source>తెలుగు</source>
        <translation>تېلۇگۇ تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="147"/>
        <source>Тоҷикӣ</source>
        <translation>تاجىك تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="148"/>
        <source>ภาษาไทย</source>
        <translation>تايلاند تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="149"/>
        <source>ትግርኛ</source>
        <translation>تىگرىنيا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="150"/>
        <source>Türkmen</source>
        <translation>تۈركمەن تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="151"/>
        <source>Setswana</source>
        <translation>سۋانا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="152"/>
        <source>Türkçe</source>
        <translation>تۈرك تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="153"/>
        <source>Xitsonga</source>
        <translation>سونگا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="154"/>
        <source>Татарский</source>
        <translation>تاتار تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="155"/>
        <source>ئۇيغۇرچە</source>
        <translation>ئۇيغۇرچە</translation>
    </message>
    <message>
        <location filename="language.h" line="156"/>
        <source>Українська</source>
        <translation>ئۇكرائىن تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="157"/>
        <source>اردو</source>
        <translation>ئوردۇ تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="158"/>
        <source>Oʻzbekcha</source>
        <translation>ئۇزبىك تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="159"/>
        <source>Uzbek (Cyrillic)</source>
        <translation>ئۇزبىك تىلى (سىرىلچە)</translation>
    </message>
    <message>
        <location filename="language.h" line="160"/>
        <source>Venda</source>
        <translation>ۋېندا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="161"/>
        <source>Tiếng Việt</source>
        <translation>ۋيېتنام تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="162"/>
        <source>Walon</source>
        <translation>ۋاللۇن تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="163"/>
        <source>Wolof</source>
        <translation>ۋولوف تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="164"/>
        <source>isixhosa</source>
        <translation>خوسا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="165"/>
        <source>ייִדיש</source>
        <translation>يىددىش تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="166"/>
        <source>Yorùbá</source>
        <translation>يورۇبا تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="167"/>
        <source>简体中文</source>
        <translation>ئاددىيلاشتۇرۇلغان خەنزۇ تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="168"/>
        <source>繁體中文(香港)</source>
        <translation>مۇرەككەپ خەنزۇ تىلى (شياڭگاڭ)</translation>
    </message>
    <message>
        <location filename="language.h" line="169"/>
        <source>正體中文</source>
        <translation>قېلىپلاشقان خەنزۇ تىلى</translation>
    </message>
    <message>
        <location filename="language.h" line="170"/>
        <source>isiZulu</source>
        <translation>زۇلۇ تىلى</translation>
    </message>
</context>
</TS>